
-----------------------------------------------------------------------------------
-- Name : nUI_Enhancement_MultiView.lua                                        
-- Copyright : Tina Kirby AKA Xrystal (C) 2012-2013 All Rights Reserved      
-- Contact : xrystal@swangen.co.uk                                           
-- Download Sites :                                                          
-- http://www.wowinterface.com
--------------------------------------------------------------------------------

-- Get Local Addonwide Data
local addonName,addonData = ...

-- Localise for easier access
local Translate = addonData.Translate
local svData = nUI_EMVData

svData = {
	UI = { 
		BottomOffset = {
			Center = { 
				ptSelf = "BOTTOM", 
				ptConnector = "BOTTOM",
				X = 0, 
				Y = 0, 
			},
			Left = { 
				Self = "BOTTOMLEFT", 
				Connector = "BOTTOMLEFT",
				X = 0, 
				Y = 0,
			},
			Right = { 
				Self = "BOTTOMRIGHT", 
				Connector = "BOTTOMRIGHT",
				X = 0, 
				Y = 0,
			},
		},
		TopOffset = { 
			Center = { 
				ptSelf = "BOTTOM", 
				ptConnector = "TOP",
				X = 0, 
				Y = 0, 
			},
			Left = { 
				Self = "BOTTOMLEFT", 
				Connector = "TOPLEFT",
				X = 0, 
				Y = 0,
			},
			Right = { 
				Self = "BOTTOMRIGHT", 
				Connector = "TOPRIGHT",
				X = 0, 
				Y = 0,
			},
		},
	},
	BazookaOffset = {
		Top = {
			X = 0, 
			Y = 0,
		},
		Bottom = {
			X = 0,
			Y = 0,
		},
	},
}

-- Simply change the X and Y values above and the Center below to Left or Right to align it
-- Localize for easier access
local bottomOffset = svData.UI.BottomOffset.Center
local topOffset = svData.UI.TopOffset.Center
local bottomBazooka = svData.BazookaOffset.Bottom
local topBazooka = svData.BazookaOffset.Top

-- Initialise Locators
nUI_BottomBarsLocator:SetPoint( bottomOffset.ptSelf, UIParent, bottomOffset.ptConnector, bottomOffset.X, bottomOffset.Y )
nUI_TopBarsLocator:SetPoint( topOffset.ptSelf, UIParent, topOffset.ptConnector, topOffset.X, topOffset.Y );

-- Taken from nUI_Bazooka.lua in nUI Addon
local function pre180()
	local BAZOOKA_VERSION = GetAddOnMetadata('Bazooka', 'Version')
	if (BAZOOKA_VERSION < '1.8.0') then
		local vBazookaTop = false
		local vBazookaBottom = false
		local bar
		
		for i = 1, Bazooka.numBars do
			bar = Bazooka.bars[i]
			if (bar) then
				if (bar.db.attach == "top") then
					vBazookaTop = bar.id
				end
				if (bar.db.attach == "bottom") then
					vBazookaBottom = bar.id
				end
			end
		end
		
		nUI_TopBarsLocator:ClearAllPoints()	  
		if (vBazookaTop) then
			nUI_TopBarsLocator:SetPoint("BOTTOM", "BazookaBar_" .. vBazookaTop, "BOTTOM", topBazooka.X, topBazooka.Y);
		else
			nUI_TopBarsLocator:SetPoint("BOTTOM", UIParent, "TOP", topBazooka.X, topBazooka.Y);
		end
		
		nUI_BottomBarsLocator:ClearAllPoints()
		if (vBazookaBottom) then
			nUI_BottomBarsLocator:SetPoint("TOP", "BazookaBar_" .. vBazookaBottom, "TOP", bottomBazooka.X, bottomBazooka.Y);
		else
			nUI_BottomBarsLocator:SetPoint("TOP", UIParent, "BOTTOM", bottomBazooka.X, bottomBazooka.Y);
		end
		
		return true
	end
	
	return false
end

-- Taken from nUI_Bazooka.lua in nUI Addon
local function DetectBazooka_Bars()
	
	if (pre180() == true) then return end

	nUI_TopBarsLocator:ClearAllPoints()
	if (Bazooka.TopAnchor) then
    	nUI_TopBarsLocator:SetPoint("BOTTOM", Bazooka.TopAnchor, "BOTTOM", topBazooka.X, topBazooka.Y)
    else
		nUI_TopBarsLocator:SetPoint("BOTTOM", UIParent, "TOP", topBazooka.X, topBazooka.Y)
	end
	
	nUI_BottomBarsLocator:ClearAllPoints()
	if (Bazooka.BottomAnchor) then
    	nUI_BottomBarsLocator:SetPoint("TOP", Bazooka.BottomAnchor, "TOP", bottomBazooka.X, bottomBazooka.Y)
    else
		nUI_BottomBarsLocator:SetPoint("TOP", UIParent, "BOTTOM", bottomBazooka.X, bottomBazooka.Y)
	end
	
end

local function OnEvent(self,event,...)
	if event == "PLAYER_LOGIN" then
		if IsAddOnLoaded("Bazooka") then
			Bazooka = LibStub("AceAddon-3.0"):GetAddon("Bazooka")
			if Bazooka then
				DetectBazooka_Bars()
			end
		end
	end
end

local nUIEMVEvents = CreateFrame("Frame","nUIEMVEvents",UIParent)
nUIEMVEvents:SetScript("OnEvent",OnEvent)
nUIEMVEvents:RegisterEvent("PLAYER_LOGIN")